@@ -258,7 +258,7 @@ parse_progress_line (FrCommand  *comm,
 
 	prefix_len = strlen (prefix);
 	if (strncmp (line, prefix, prefix_len) == 0) {
-		if (fr_archive_progress_get_total_files (archive) > 1) {
+		if (fr_archive_progress_get_total_files (archive) > 0) {
 			fr_archive_progress (archive, fr_archive_progress_inc_completed_files (archive, 1));
 		}
 		else {
@@ -327,12 +327,12 @@ process_line__add (char     *line,
 
 
 static void
-fr_command_rar_add (FrCommand     *comm,
-		    const char    *from_file,
-		    GList         *file_list,
-		    const char    *base_dir,
-		    gboolean       update,
-		    gboolean       recursive)
+fr_command_rar_add (FrCommand  *comm,
+		    const char *from_file,
+		    GList      *file_list,
+		    const char *base_dir,
+		    gboolean    update,
+		    gboolean    follow_links)
 {
 	GList *scan;
 
@@ -351,6 +351,9 @@ fr_command_rar_add (FrCommand     *comm,
 	else
 		fr_process_add_arg (comm->process, "a");
 
+	if (! follow_links)
+		fr_process_add_arg (comm->process, "-ol");
+
 	switch (FR_ARCHIVE (comm)->compression) {
 	case FR_COMPRESSION_VERY_FAST:
 		fr_process_add_arg (comm->process, "-m1"); break;
@@ -671,6 +674,7 @@ fr_command_rar_init (FrCommandRar *self)
 	base->propAddCanUpdate             = TRUE;
 	base->propAddCanReplace            = TRUE;
 	base->propAddCanStoreFolders       = TRUE;
+	base->propAddCanStoreLinks         = TRUE;
 	base->propExtractCanAvoidOverwrite = TRUE;
 	base->propExtractCanSkipOlder      = TRUE;
 	base->propExtractCanJunkPaths      = TRUE;
